#
# spec file for package ghc-optics-th
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name optics-th
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4.1
Release:        bp156.1.1
Summary:        Optics construction using TemplateHaskell
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/6.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-optics-core-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-th-abstraction-devel
BuildRequires:  ghc-transformers-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tagged-devel
%endif

%description
This package is part of the '<https://hackage.haskell.org/package/optics
optics>' package family. It provides machinery to construct optics using
'TemplateHaskell'.

See the 'template-haskell-optics' package for optics to work with
'template-haskell' types.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%changelog
* Thu Nov 16 2023 Peter Simons <psimons@suse.com>
- Update optics-th to version 0.4.1 revision 6.
  [#] optics-th-0.4.1 (2022-03-22)
  * Add support for GHC-9.2
* Mon Nov 15 2021 psimons@suse.com
- Update optics-th to version 0.4 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Feb 23 2021 psimons@suse.com
- Update optics-th to version 0.4.
  [#] optics-th-0.4 (2021-02-22)
  * Add support for GHC-9.0
  * Print missing language extensions during TH generation of labels if there are
    any ([#352](https://github.com/well-typed/optics/pull/352))
  * Add support for getters of rank1 polymorphic fields to optics generated with
    the `makeFieldLabels` family of functions
    ([#365](https://github.com/well-typed/optics/pull/365))
  * Extend support of type-changing optics generated with the `makeFieldLabels`
    family to type parameters that are phantom and applied to non-injective type
    families
    ([#365](https://github.com/well-typed/optics/pull/365))
  * Fix TH generation of optics for poly-kinded data families
    ([#378](https://github.com/well-typed/optics/pull/378))
  * Fix `declareFieldLabels` when a field type refers to a type defined in the
    same quote
    ([#380](https://github.com/well-typed/optics/pull/380))
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct  6 2020 psimons@suse.com
- Update optics-th to version 0.3.0.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Sep  1 2020 psimons@suse.com
- Add optics-th at version 0.3.0.2.
